from django.utils.translation import gettext as _

from material import Layout, Row

from aleksis.core.forms import ActionForm
from aleksis.core.mixins import ExtensibleForm

from .models.base import Client
from .models.invoice import InvoiceGroup
from .tasks import email_invoice


def send_emails_action(modeladmin, request, queryset):
    """Send e-mails for selected invoices."""
    email_invoice.delay(list(queryset.values_list("token", flat=True)))


send_emails_action.short_description = _("Send e-mails")
send_emails_action.permission = "tezor.send_invoice_email"


class InvoicesActionForm(ActionForm):
    def get_actions(self):
        return [send_emails_action]


class EditClientForm(ExtensibleForm):
    """Form to create or edit clients."""

    layout = Layout("name", "email")

    class Meta:
        model = Client
        exclude = []


class EditInvoiceGroupForm(ExtensibleForm):

    layout = Layout(Row("name", "template_name"))

    class Meta:
        model = InvoiceGroup
        exclude = ["client"]
